//%attributes = {"shared":true}
C_POINTER:C301($1; $imageDataPtr)  // @param: A pointer to a BLOB containing the image data.
C_OBJECT:C1216($2; $options)  // @param: Options. @optional
C_TEXT:C284($0; $imgDocRef)  // @param: The image document reference.

// @desc: Create an image document instance referencing image data provided in a BLOB.

// @doc: Create an image document instance referencing image data provided in a BLOB.
// The image document reference is returned in ``imgDocRef``.
//
// If the method call fails for some reason, an empty string is returned and the
// Q2Pix :ref:`error info <ImgErr_GetInfo>` is set accordingly.
//
// Parameter ``imageDataPtr`` is a pointer to a BLOB containing the image data.
//
// The optional ``options`` object parameter may contain the following key/value pairs:
//
// .. list-table::
//    :widths: 30 70
//    :header-rows: 1
//
//    * - Key
//      - Description
//    * - "Format"
//      - The option's value is the format identifier (a string) of the
//        specified image data. This option does not restrict the reading of the image data to the
//        specified format, but rather acts as a 'hint' to the plug-in and underlying OS imaging
//        libraries.
//    * - "Password"
//      - The option's value is the password (a string) for a protected PDF document.
//    * - "AllowUserInteraction"
//      - The option's value is a boolean denoting whether user interaction is allowed.
//        Default value is ``True``.
//
// If the specified BLOB contains a locked PDF document and opening
// it fails with an authorization error (``"Q2Pix"``/``kQ2PixErrAuth``), a password entry dialog
// is presented to the user. If the user enters the correct password, the PDF document is opened
// and the document reference is returned. If the user cancels the dialog, the Q2Pix error info
// is set to ``"Q2Pix"``/``kQ2PixErrAuth`` and the method returns an empty string. If the user enters
// an invalid password, the method keeps running the password request dialog until the user either
// enters the correct dialog, or cancels.
//
// The ``AllowUserInteraction`` property defaults to ``True``, which allows this command to
// present the PDF password dialog, if necessary. When calling this
// method in a batch or unattended process, you may consider setting this to ``False`` so as the
// process is not halted by the dialog waiting for user input.
//
// .. note:: This method is a wrapper for the :cc4d:xmethod:`ImgDoc_CreateWithBLOB_JSN` plug-in method.
//           In addition to converting the ``options`` object to JSON for passing to the plug-in,
//           it offers some extra functionality in the form of the PDF password dialog.
//

ASSERT:C1129(Count parameters:C259>=1)

$imageDataPtr:=$1
ASSERT:C1129(Type:C295($imageDataPtr->)=Is BLOB:K8:12)

If (Count parameters:C259>1)
	$options:=$2
End if 

C_TEXT:C284($optionsJSON)
If (OB Is defined:C1231($options))
	$optionsJSON:=JSON Stringify:C1217($options)
End if 

C_BOOLEAN:C305($allowInteraction)
$allowInteraction:=Choose:C955($options["AllowUserInteraction"]#Null:C1517; \
Bool:C1537($options["AllowUserInteraction"]); True:C214)

$imgDocRef:=ImgDoc_CreateWithBLOB_JSN:P11667:6($imageDataPtr->; $optionsJSON)
If (($imgDocRef="") & $allowInteraction)
	
	C_BOOLEAN:C305($break)
	$break:=False:C215
	
	While (Not:C34($break)\
		 & ($imgDocRef="")\
		 & (ImgErr_GetDomain="Q2Pix") & (ImgErr_GetCode=kQ2PixErrAuth))
		C_TEXT:C284($password)
		$password:=ImgDlog_RequestPDFPassword
		If ($password#"")
			C_OBJECT:C1216($localOptions)
			If (OB Is defined:C1231($options))
				$localOptions:=OB Copy:C1225($options)
			End if 
			OB SET:C1220($localOptions; "Password"; $password)
			$optionsJSON:=JSON Stringify:C1217($localOptions)
			$imgDocRef:=ImgDoc_CreateWithBLOB_JSN:P11667:6($imageDataPtr->; $optionsJSON)
		Else 
			$break:=True:C214
		End if 
	End while 
	
End if 

$0:=$imgDocRef
